==> babel-plugin-macros-2.8.5.tgz: babel-plugin-macros/README.md <==
# Installation
> `npm install --save @types/babel-plugin-macros`

# Summary
This package contains type definitions for babel-plugin-macros (https://github.com/kentcdodds/babel-plugin-macros).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/babel-plugin-macros.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/babel-plugin-macros/index.d.ts)
````ts
// Type definitions for babel-plugin-macros 2.8
// Project: https://github.com/kentcdodds/babel-plugin-macros
// Definitions by: Billy Kwok <https://github.com/billykwok>
//                 Jake Runzer <https://github.com/coffee-cup>
//                 Ifiok Jr. <https://github.com/ifiokjr>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped
// Minimum TypeScript Version: 3.4

import * as Babel from '@babel/core';

export = babelPluginMacros;

declare namespace babelPluginMacros {
    interface References {
        [key: string]: Babel.NodePath[];
    }

    interface Options {
        configName?: string | undefined;
    }

    interface MacroParams {
        references: { default: Babel.NodePath[] } & References;
        state: Babel.PluginPass;
        babel: typeof Babel;
        config?: { [key: string]: any } | undefined;
    }

    type MacroHandler = (params: MacroParams) => void;

    class MacroError extends Error {}

    function createMacro(handler: MacroHandler, options?: Options): any;
}

declare function babelPluginMacros(babel: typeof Babel, options: any): Babel.PluginObj;

````

### Additional Details
 * Last updated: Tue, 06 Jul 2021 18:05:39 GMT
 * Dependencies: [@types/babel__core](https://npmjs.com/package/@types/babel__core)
 * Global values: none

# Credits
These definitions were written by [Billy Kwok](https://github.com/billykwok), [Jake Runzer](https://github.com/coffee-cup), and [Ifiok Jr.](https://github.com/ifiokjr).

==> babel-plugin-macros-3.1.0.tgz: babel-plugin-macros/README.md <==
# Installation
> `npm install --save @types/babel-plugin-macros`

# Summary
This package contains type definitions for babel-plugin-macros (https://github.com/kentcdodds/babel-plugin-macros).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/babel-plugin-macros.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/babel-plugin-macros/index.d.ts)
````ts
// Type definitions for babel-plugin-macros 3.1
// Project: https://github.com/kentcdodds/babel-plugin-macros
// Definitions by: Billy Kwok <https://github.com/billykwok>
//                 Jake Runzer <https://github.com/coffee-cup>
//                 Ifiok Jr. <https://github.com/ifiokjr>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped
// Minimum TypeScript Version: 3.4

import * as Babel from '@babel/core';

export = babelPluginMacros;

declare namespace babelPluginMacros {
    interface References {
        [key: string]: Babel.NodePath[];
    }

    interface Options {
        configName?: string | undefined;
    }

    interface MacroParams {
        references: { default: Babel.NodePath[] } & References;
        state: Babel.PluginPass;
        babel: typeof Babel;
        config?: { [key: string]: any } | undefined;
        source: string;
        isBabelMacrosCall: boolean;
    }

    type MacroHandler = (params: MacroParams) => void;

    class MacroError extends Error {}

    function createMacro(handler: MacroHandler, options?: Options): any;
}

declare function babelPluginMacros(babel: typeof Babel, options: any): Babel.PluginObj;

````

### Additional Details
 * Last updated: Fri, 24 Feb 2023 05:32:34 GMT
 * Dependencies: [@types/babel__core](https://npmjs.com/package/@types/babel__core)
 * Global values: none

# Credits
These definitions were written by [Billy Kwok](https://github.com/billykwok), [Jake Runzer](https://github.com/coffee-cup), and [Ifiok Jr.](https://github.com/ifiokjr).
